package com.djhk.uav.uav.service;

import com.djhk.common.core.domain.R;
import com.djhk.common.core.page.TableDataInfo;
import com.djhk.uav.uav.model.UavOrganization;

import java.util.List;
import java.util.Map;

/**
 * 无人机编队Service接口
 *
 * @author jiachengshuai
 * @date 2023-02-28
 */
public interface IUavOrganizationService
{
    /**
     * 查询无人机编队
     *
     * @param id 无人机编队主键
     * @return 无人机编队
     */
    public R<UavOrganization> selectUavOrganizationById(Long id);

    /**
     * 查询无人机编队列表
     *
     * @param param 无人机编队
     * @return 无人机编队集合
     */
    public R<List<UavOrganization>> selectUavOrganizationList(Map<String, Object> param);

    /**
     * 新增无人机编队
     *
     * @param uavOrganization 无人机编队
     * @return 结果
     */
    public R insertUavOrganization(UavOrganization uavOrganization);

    /**
     * 修改无人机编队
     *
     * @param uavOrganization 无人机编队
     * @return 结果
     */
    public R updateUavOrganization(UavOrganization uavOrganization);

    /**
     * 批量删除无人机编队
     *
     * @param ids 需要删除的无人机编队主键集合
     * @return 结果
     */
    public R deleteUavOrganizationByIds(Long[] ids);

    /**
     * 删除无人机编队信息
     *
     * @param param 无人机编队主键
     * @return 结果
     */

    TableDataInfo selectOrganizationTableData(Map<String, Object> param);
}
